from django.db import models
from django.contrib.auth.models import User


class Collection(models.Model):
    """A collection is a grouping of Volumes.

    Usually a library will have a number of different collections,
    e.g. "Southeast Asia Collection", "Correspondence of John Irving", etc.
    """
    name = models.CharField(max_length=200)
    source = models.CharField(max_length=200)
    publication_date = models.DateTimeField('date published')
    curator = models.ForeignKey(User)
    def __unicode__(self):
        return self.name


class Storage(models.Model):
    """Storage is a reference to the physical media where the work is located.

    Volumes can be found by using the Storage mount_point as the root.
    """
    name = models.CharField(max_length=100)
    mount_point = models.CharField(max_length=100)
    def __unicode__(self):
        return self.name
    class Meta:
        ordering = ['name']
        verbose_name_plural = 'storage'

class Set(models.Model):
    name = models.CharField(max_length=200)
    def __unicode__(self):
        return self.name


class Condition(models.Model):
    name = models.CharField(max_length=50)
    def __unicode__(self):
        return self.name


class Person(models.Model):
    name = models.CharField(max_length=50)
    def __unicode__(self):
        return self.name


class PrintType(models.Model):
    name = models.CharField(max_length=50)
    def __unicode__(self):
        return self.name


class Language(models.Model):
    name = models.CharField(max_length=20)
    def __unicode__(self):
        return self.name


class Subject(models.Model):
    name = models.CharField(max_length=50)
    def __unicode__(self):
        return self.name


class MediaType(models.Model):
    name = models.CharField(max_length=20)
    def __unicode__(self):
        return self.name


class Metadata(models.Model):
    """Metadata for a volume."""
    def __unicode__(self):
        return self.nlvnpf_num
    condition = models.ForeignKey(Condition)
    # contributor = models.CharField(max_length=20)
    coverage = models.CharField(max_length=50)
    creator_hn = models.CharField(max_length=100)
    creator_qn = models.CharField(max_length=500)
    date_dl = models.CharField(max_length=50)
    date_hn = models.CharField(max_length=50)
    date_image = models.CharField(max_length=10)
    date_qn = models.CharField(max_length=200)
    description = models.CharField(max_length=300)
    description_en = models.CharField(max_length=300)
    digitizer = models.ForeignKey(Person)
    print_type = models.ForeignKey(PrintType)
    formats = models.CharField(max_length=20)
    height = models.CharField(max_length=10)
    legacy_id = models.IntegerField()
    # illustration = models.CharField(max_length=20)
    language = models.ForeignKey(Language)
    nlv_num = models.CharField(max_length=20)
    nlvnpf_num = models.CharField(max_length=20)
    notes = models.CharField(max_length=500)
    notes_en = models.CharField(max_length=200)
    pages = models.IntegerField()
    place_hn = models.CharField(max_length=100)
    place_qn = models.CharField(max_length=100)
    publisher_hn = models.CharField(max_length=100)
    publisher_qn = models.CharField(max_length=100)
    relation = models.CharField(max_length=50)
    rights = models.CharField(max_length=100)
    source = models.CharField(max_length=100)
    subject = models.ForeignKey(Subject)
    title_alt_hn = models.CharField(max_length=200)
    title_alt_qn = models.CharField(max_length=200)
    title_hn = models.CharField(max_length=200)
    title_qn = models.CharField(max_length=200)
    media_type = models.ForeignKey(MediaType)
    width = models.CharField(max_length=10)
    class Meta:
        verbose_name_plural = 'metadata'

class Volume(models.Model):
    """A Volume is a particular bound work.

    A set, such as a reference work, may have multiple volumes.
    """
    name = models.CharField(max_length=100)
    nlvnpf = models.CharField(max_length=20)
    collection = models.ForeignKey(Collection)
    #_set = models.ForeignKey(Set, null=True, blank=True)
    storage = models.ForeignKey(Storage, null=True)
    md = models.ForeignKey(Metadata)
    def __unicode__(self):
        return self.name
    class Meta:
        ordering = ['name']


class Page(models.Model):
    name = models.CharField(max_length=200)
    volume = models.ForeignKey(Volume)
    def __unicode__(self):
        return self.name


class Image(models.Model):
    name = models.CharField(max_length=200)
    page = models.ForeignKey(Page)
    def __unicode__(self):
        return self.name
